@@ -1,22 +1,29 @@
 local httputils = {}
 
 
-function httputils.get_request_data(name, queries, body, headers)
+function httputils.get_request_data(name, body, queries, headers, cookies, get_name, header_name, cookie_name)
     local value = nil
 
-    if headers == nil then
-        headers = {}
-    end
     if body == nil then
         body = {}
     end
+    if headers == nil then
+        headers = {}
+    end
     if queries == nil then
         queries = {}
     end
-
-    value = headers[name]
-    if value ~= nil then
-        return value
+    if cookies == nil then
+        cookies = {}
+    end
+    if get_name == nil then
+        get_name = name
+    end
+    if header_name == nil then
+        header_name = name
+    end
+    if cookie_name == nil then
+        cookie_name = name
     end
 
     value = body[name]
@@ -24,7 +31,17 @@ function httputils.get_request_data(name, queries, body, headers)
         return value
     end
 
-    value = queries[name]
+    value = queries[get_name]
+    if value ~= nil then
+        return value
+    end
+
+    value = headers[header_name]
+    if value ~= nil then
+        return value
+    end
+
+    value = cookies[cookie_name]
     if value ~= nil then
         return value
     end
